@@ -1,7 +1,7 @@
 use setup;
 
 macro_rules! operations(
-    ($($operator:ident => [$($operand:expr),*],)*) => ({
+    ($($operator:ident: [$($operand:expr),*],)*) => ({
         use postscript::compact::operation::{Operand, Operator};
         use std::collections::HashMap;
         let mut operations = HashMap::new();
@@ -16,7 +16,6 @@ fn char_sets() {
 
     let set = setup();
     let vector = &set.char_sets;
-
     assert_eq!(vector.len(), 1);
     match &vector[0] {
         &CharSet::Format1(..) => {},
@@ -28,7 +27,6 @@ fn char_sets() {
 fn char_strings() {
     let set = setup();
     let vector = &set.char_strings;
-
     assert_eq!(vector.len(), 1);
     assert_eq!(vector[0].len(), 547);
 }
@@ -40,7 +38,6 @@ fn encodings() {
     let set = setup();
     let vector = &set.encodings;
     let strings = &set.strings;
-
     assert_eq!(vector.len(), 1);
     match &vector[0] {
         encoding @ &Encoding::Standard => {
@@ -54,19 +51,18 @@ fn encodings() {
 fn global_dictionaries() {
     let set = setup();
     let vector = &set.global_dictionaries;
-
     assert_eq!(vector.len(), 1);
     assert_eq!(&*vector[0], &operations!(
-        Version => [709],
-        Notice => [710],
-        Copyright => [711],
-        FullName => [712],
-        FamilyName => [712],
-        Weight => [388],
-        FontBBox => [-178, -335, 1138, 918],
-        CharSet => [8340],
-        CharStrings => [8917],
-        Private => [65, 33671],
+        Version: [709],
+        Notice: [710],
+        Copyright: [711],
+        FullName: [712],
+        FamilyName: [712],
+        Weight: [388],
+        FontBBox: [-178, -335, 1138, 918],
+        CharSet: [8340],
+        CharStrings: [8917],
+        Private: [65, 33671],
     ));
 }
 
@@ -74,7 +70,6 @@ fn global_dictionaries() {
 fn global_subroutines() {
     let set = setup();
     let index = &set.global_subroutines;
-
     assert_eq!(index.len(), 181);
 }
 
@@ -82,7 +77,6 @@ fn global_subroutines() {
 fn header() {
     let set = setup();
     let table = &set.header;
-
     assert_eq!(table.major, 1);
     assert_eq!(table.minor, 0);
     assert_eq!(table.header_size, 4);
@@ -91,21 +85,30 @@ fn header() {
 
 #[test]
 fn local_dictionaries() {
-    use postscript::compact::operation::Operator;
-
     let set = setup();
     let vector = &set.local_dictionaries;
-
     assert_eq!(vector.len(), 1);
-    assert_eq!(vector[0].len(), 13);
-    assert_eq!(ok!(vector[0].get(Operator::BlueScale)), &[0.0375]);
+    assert_eq!(&*vector[0], &operations!(
+        DefaultWidthX: [370],
+        FamilyOtherBlues: [-249, 10],
+        BlueValues: [-20, 20, 473, 18, 34, 15, 104, 15, 10, 20, 40, 20],
+        StemSnapH: [41, 15],
+        StdHW: [41],
+        NominalWidthX: [604],
+        StdVW: [85],
+        OtherBlues: [-249, 10],
+        BlueFuzz: [0],
+        Subrs: [65],
+        FamilyBlues: [-20, 20, 473, 18, 34, 15, 104, 15, 10, 20, 40, 20],
+        BlueScale: [0.0375],
+        StemSnapV: [85, 10],
+    ));
 }
 
 #[test]
 fn local_subroutines() {
     let set = setup();
     let vector = &set.local_subroutines;
-
     assert_eq!(vector.len(), 1);
     assert_eq!(vector[0].len(), 180);
 }
@@ -114,7 +117,6 @@ fn local_subroutines() {
 fn names() {
     let set = setup();
     let vector = &set.names;
-
     assert_eq!(vector.len(), 1);
     assert_eq!(&vector[0], "SourceSerifPro-Regular");
 }
@@ -123,7 +125,6 @@ fn names() {
 fn strings() {
     let set = setup();
     let index = &set.strings;
-
     assert_eq!(index.len(), 322);
     assert_eq!(ok!(index.get(175)), "Aring");
     assert_eq!(ok!(index.get(500)), "nine.tosf");
